//==========================  Open Steamworks  ================================
//
// This file is part of the Open Steamworks project. All individuals associated
// with this project do not claim ownership of the contents
// 
// The code, comments, and all related files, projects, resources,
// redistributables included with this project are Copyright Valve Corporation.
// Additionally, Valve, the Valve logo, Half-Life, the Half-Life logo, the
// Lambda logo, Steam, the Steam logo, Team Fortress, the Team Fortress logo,
// Opposing Force, Day of Defeat, the Day of Defeat logo, Counter-Strike, the
// Counter-Strike logo, Source, the Source logo, and Counter-Strike Condition
// Zero are trademarks and or registered trademarks of Valve Corporation.
// All other trademarks are property of their respective owners.
//
//=============================================================================

#ifndef ISTEAMREMOTESTORAGE014_H
#define ISTEAMREMOTESTORAGE014_H
#ifdef _WIN32
#pragma once
#endif

#include "SteamTypes.h"
#include "RemoteStorageCommon.h"

//-----------------------------------------------------------------------------
// Purpose: Functions for accessing, reading and writing files stored remotely 
//			and cached locally
//-----------------------------------------------------------------------------
abstract_class ISteamRemoteStorage014
{
public:
	// NOTE
	//
	// Filenames are case-insensitive, and will be converted to lowercase automatically.
	// So "foo.bar" and "Foo.bar" are the same file, and if you write "Foo.bar" then
	// iterate the files, the filename returned will be "foo.bar".
	//

	// file operations
	virtual bool	FileWrite( const char *pchFile, const void *pvData, int32 cubData ) = 0;
	virtual int32	FileRead( const char *pchFile, void *pvData, int32 cubDataToRead ) = 0;

	CALL_RESULT( RemoteStorageFileWriteAsyncComplete_t )
	virtual SteamAPICall_t FileWriteAsync( const char *pchFile, const void *pvData, uint32 cubData ) = 0;

	CALL_RESULT(RemoteStorageFileReadAsyncComplete_t)
	virtual SteamAPICall_t FileReadAsync( const char *pchFile, uint32 nOffset, uint32 cubToRead ) = 0;
	virtual bool	FileReadAsyncComplete( SteamAPICall_t hReadCall, void *pvBuffer, uint32 cubToRead ) = 0;
	
	virtual bool	FileForget( const char *pchFile ) = 0;
	virtual bool	FileDelete(const char *pchFile) = 0;
	CALL_RESULT(RemoteStorageFileShareResult_t)
	virtual SteamAPICall_t FileShare( const char *pchFile ) = 0;
	virtual bool	SetSyncPlatforms( const char *pchFile, ERemoteStoragePlatform eRemoteStoragePlatform ) = 0;

	virtual GID_t FileWriteStreamOpen( const char *pchFile ) = 0;
	virtual EResult FileWriteStreamWriteChunk( GID_t hStream, const void *pvData, int32 cubData ) = 0;
	virtual EResult FileWriteStreamClose( GID_t hStream ) = 0;
	virtual EResult FileWriteStreamCancel( GID_t hStream ) = 0;

	// file information
	virtual bool	FileExists( const char *pchFile ) = 0;
	virtual bool	FilePersisted( const char *pchFile ) = 0;
	virtual int32	GetFileSize( const char *pchFile ) = 0;
	virtual int64	GetFileTimestamp( const char *pchFile ) = 0;
	virtual ERemoteStoragePlatform GetSyncPlatforms( const char *pchFile ) = 0;

	// iteration
	virtual int32 GetFileCount() = 0;
	virtual const char *GetFileNameAndSize( int iFile, int32 *pnFileSizeInBytes ) = 0;

	// configuration management
	virtual bool GetQuota(uint64 *pnTotalBytes, uint64 *puAvailableBytes) = 0;
	virtual bool IsCloudEnabledForAccount() = 0;
	virtual bool IsCloudEnabledForApp() = 0;
	virtual void SetCloudEnabledForApp( bool bEnabled ) = 0;

	// user generated content
	CALL_RESULT( RemoteStorageDownloadUGCResult_t )
	virtual SteamAPICall_t UGCDownload( UGCHandle_t hContent, uint32 uUnk ) = 0; // Returns a RemoteStorageDownloadUGCResult_t callback
	virtual bool GetUGCDownloadProgress( UGCHandle_t hContent, uint32 *puDownloadedBytes, uint32 *puTotalBytes ) = 0;
	virtual bool	GetUGCDetails( UGCHandle_t hContent, AppId_t *pnAppID, char **ppchName, int32 *pnFileSizeInBytes, CSteamID *pSteamIDOwner ) = 0;
	virtual int32	UGCRead( UGCHandle_t hContent, void *pvData, int32 cubDataToRead, uint32 uOffset, EUGCReadAction eAction ) = 0;

	// user generated content iteration
	virtual int32	GetCachedUGCCount() = 0;
	virtual UGCHandle_t GetCachedUGCHandle( int32 iCachedContent ) = 0;

	// publishing UGC
	CALL_RESULT(RemoteStoragePublishFileProgress_t)
	virtual SteamAPICall_t PublishWorkshopFile( const char *pchFile, const char *pchPreviewFile, AppId_t nConsumerAppId, const char *pchTitle, const char *pchDescription, ERemoteStoragePublishedFileVisibility eVisibility, SteamParamStringArray_t *pTags, EWorkshopFileType eWorkshopFileType ) = 0;
	virtual JobID_t CreatePublishedFileUpdateRequest( PublishedFileId_t unPublishedFileId ) = 0;
	virtual bool UpdatePublishedFileFile( JobID_t hUpdateRequest, const char *pchFile ) = 0;
	virtual bool UpdatePublishedFilePreviewFile( JobID_t hUpdateRequest, const char *pchPreviewFile ) = 0;
	virtual bool UpdatePublishedFileTitle( JobID_t hUpdateRequest, const char *pchTitle ) = 0;
	virtual bool UpdatePublishedFileDescription( JobID_t hUpdateRequest, const char *pchDescription ) = 0;
	virtual bool UpdatePublishedFileVisibility( JobID_t hUpdateRequest, ERemoteStoragePublishedFileVisibility eVisibility ) = 0;
	virtual bool UpdatePublishedFileTags( JobID_t hUpdateRequest, SteamParamStringArray_t *pTags ) = 0;
	CALL_RESULT( RemoteStorageUpdatePublishedFileResult_t )
	virtual SteamAPICall_t CommitPublishedFileUpdate( JobID_t hUpdateRequest ) = 0;

	CALL_RESULT( RemoteStorageGetPublishedFileDetailsResult_t )
	virtual SteamAPICall_t GetPublishedFileDetails( PublishedFileId_t unPublishedFileId, uint32 ) = 0;
	CALL_RESULT(RemoteStorageDeletePublishedFileResult_t)
	virtual SteamAPICall_t	DeletePublishedFile(PublishedFileId_t unPublishedFileId) = 0;
	// enumerate the files that the current user published with this app
	CALL_RESULT(RemoteStorageEnumerateUserPublishedFilesResult_t)
	virtual SteamAPICall_t	EnumerateUserPublishedFiles(uint32 unStartIndex) = 0;
	CALL_RESULT(RemoteStorageSubscribePublishedFileResult_t)
	virtual SteamAPICall_t	SubscribePublishedFile(PublishedFileId_t unPublishedFileId) = 0;
	CALL_RESULT(RemoteStorageEnumerateUserSubscribedFilesResult_t)
	virtual SteamAPICall_t	EnumerateUserSubscribedFiles(uint32 unStartIndex) = 0;
	CALL_RESULT(RemoteStorageUnsubscribePublishedFileResult_t)
	virtual SteamAPICall_t	UnsubscribePublishedFile(PublishedFileId_t unPublishedFileId) = 0;
	virtual bool UpdatePublishedFileSetChangeDescription(PublishedFileUpdateHandle_t updateHandle, const char *pchChangeDescription) = 0;
	CALL_RESULT(RemoteStorageGetPublishedItemVoteDetailsResult_t)
	virtual SteamAPICall_t	GetPublishedItemVoteDetails(PublishedFileId_t unPublishedFileId) = 0;
	CALL_RESULT(RemoteStorageUpdateUserPublishedItemVoteResult_t)
	virtual SteamAPICall_t	UpdateUserPublishedItemVote(PublishedFileId_t unPublishedFileId, bool bVoteUp) = 0;
	CALL_RESULT(RemoteStorageGetPublishedItemVoteDetailsResult_t)
	virtual SteamAPICall_t	GetUserPublishedItemVoteDetails(PublishedFileId_t unPublishedFileId) = 0;
	CALL_RESULT(RemoteStorageEnumerateUserPublishedFilesResult_t)
	virtual SteamAPICall_t	EnumerateUserSharedWorkshopFiles(CSteamID steamId, uint32 unStartIndex, SteamParamStringArray_t *pRequiredTags, SteamParamStringArray_t *pExcludedTags) = 0;
	CALL_RESULT(RemoteStoragePublishFileProgress_t)
	virtual SteamAPICall_t	PublishVideo(EWorkshopVideoProvider eVideoProvider, const char *pchVideoAccount, const char *pchVideoIdentifier, const char *pchPreviewFile, AppId_t nConsumerAppId, const char *pchTitle, const char *pchDescription, ERemoteStoragePublishedFileVisibility eVisibility, SteamParamStringArray_t *pTags) = 0;
	CALL_RESULT( RemoteStorageSetUserPublishedFileActionResult_t )
	virtual SteamAPICall_t	SetUserPublishedFileAction(PublishedFileId_t unPublishedFileId, EWorkshopFileAction eAction) = 0;
	CALL_RESULT(RemoteStorageEnumeratePublishedFilesByUserActionResult_t)
	virtual SteamAPICall_t	EnumeratePublishedFilesByUserAction(EWorkshopFileAction eAction, uint32 unStartIndex) = 0;
	// this method enumerates the public view of workshop files
	CALL_RESULT(RemoteStorageEnumerateWorkshopFilesResult_t)
	virtual SteamAPICall_t	EnumeratePublishedWorkshopFiles(EWorkshopEnumerationType eEnumerationType, uint32 unStartIndex, uint32 unCount, uint32 unDays, SteamParamStringArray_t *pTags, SteamParamStringArray_t *pUserTags) = 0;

	CALL_RESULT(RemoteStorageDownloadUGCResult_t)
	virtual SteamAPICall_t UGCDownloadToLocation(UGCHandle_t hContent, const char *pchLocation, uint32 unPriority) = 0;
};

#endif // ISTEAMREMOTESTORAGE014_H
